
#  █▀▀▀  █▀▄▀█  █▀▀█ ▀█▀  █    　  █▀▀▀█  █▀▀▀  █▄  █  █▀▀▄  █▀▀▀  █▀▀█
#  █▀▀▀  █ █ █  █▄▄█  █   █    　  ▀▀▀▄▄  █▀▀▀  █ █ █  █  █  █▀▀▀  █▄▄▀
#  █▄▄▄  █   █  █  █ ▄█▄  █▄▄█ 　  █▄▄▄█  █▄▄▄  █  ▀█  █▄▄▀  █▄▄▄  █  █

from setuptools import setup

setup(
    name='EmailSender_GhostPoltergeist',
    version='2.1.0',
    description='A python script program to send emails using SMTP',
    author='Harold Edsel F. Cabaluna',
    author_email='EdselCabaluna21@gmail.com',
    license='MIT',
    keywords='email sender smtp',
    packages=['EmailSender_GhostPoltergeist'],
)